Struct sp_runtime::generic::UncheckedExtrinsic
source · pub struct UncheckedExtrinsic<Address, Call, Signature, Extra>where
Extra: SignedExtension,{
pub signature: Option<(Address, Signature, Extra)>,
pub function: Call,
}Expand description
An extrinsic right from the external world. This is unchecked and so can contain a signature.
An extrinsic is formally described as any external data that is originating from the outside of the runtime and fed into the runtime as a part of the block-body.
Inherents are special types of extrinsics that are placed into the block by the block-builder. they are unsigned because the assertion is that they are “inherently true” by virtue of getting past all validators.
Transaction are all other statements provided by external entities that the chain deems values and decided to include in the block. This value is typically in the form of fee payment, but it could in principle be any other interaction. Transactions are either signed, or unsigned. A sensible transaction pool should ensure that only transactions that are worthwhile are considered for block-building.
flowchart TD
E(Extrinsic) ---> I(Inherent);
E --> T(Transaction)
T --> ST("Signed (aka. Transaction)")
T --> UT(Unsigned)
This type is by no means enforced within substrate, but given its generic-ness, it is highly likely that for most use-cases it will suffice. Thus, the encoding of this type will dictate exactly what bytes should be sent to a runtime to transact with it.
This can be checked using Checkable, yielding a CheckedExtrinsic, which is the
counterpart of this type after its signature (and other non-negotiable validity checks) have
passed.
Fields
signature: Option<(Address, Signature, Extra)>The signature, address, number of extrinsics have come before from the same signer and an era describing the longevity of this transaction, if this is a signed extrinsic.
None if it is unsigned or an inherent.
function: CallThe function that should be called.
Implementations
sourceimpl<Address, Call, Signature, Extra: SignedExtension> UncheckedExtrinsic<Address, Call, Signature, Extra>
impl<Address, Call, Signature, Extra: SignedExtension> UncheckedExtrinsic<Address, Call, Signature, Extra>
sourcepub fn new_signed(
function: Call,
signed: Address,
signature: Signature,
extra: Extra
) -> Self
pub fn new_signed( function: Call, signed: Address, signature: Signature, extra: Extra ) -> Self
New instance of a signed extrinsic aka “transaction”.
sourcepub fn new_unsigned(function: Call) -> Self
pub fn new_unsigned(function: Call) -> Self
New instance of an unsigned extrinsic aka “inherent”.